import customtkinter as ctk
import requests
from PIL import Image, ImageTk
from tkinter import messagebox
import io

BACKEND_HOST = "http://127.0.0.1:8000"  # Adjust if needed


def fix_url(url):
    """
    Fix the URL to ensure it points to the correct static file location.
    """
    if url.startswith("http"):
        return url
    return f"{BACKEND_HOST}/static/{url}"


def view_shop_frame(parent, switch_func, API_URL, token, shop_id):
    """
    CustomTkinter-based frame to display shop details and products.
    """
    frame = ctk.CTkFrame(parent, fg_color="transparent")

    # Fetch shop details and products from the backend
    headers = {"Authorization": f"Bearer {token}"}
    try:
        response = requests.get(f"{API_URL}/shops/get/{shop_id}", headers=headers)
        if response.status_code == 200:
            data = response.json()
            shop_data = data.get("shop", {})
            products = data.get("products", [])
        else:
            messagebox.showerror("Error", f"Failed to fetch shop data. Status: {response.status_code}")
            return frame
    except Exception as e:
        messagebox.showerror("Error", f"Request error: {e}")
        return frame

    # ------------- TOP LAYER (Shop Image and Details) -------------
    top_layer = ctk.CTkFrame(frame, fg_color="transparent")
    top_layer.place(relx=0, rely=0, relwidth=1, relheight=0.4)

    # Shop Image
    shop_image_label = ctk.CTkLabel(top_layer, text="")
    shop_image_label.place(relx=0.05, rely=0.1, relwidth=0.3, relheight=0.8)

    shop_image_url = shop_data.get("image_url")
    if shop_image_url:
        fixed_url = fix_url(shop_image_url)
        try:
            resp = requests.get(fixed_url)
            if resp.status_code == 200:
                pil_img = Image.open(io.BytesIO(resp.content)).resize((200, 200))
                tk_img = ImageTk.PhotoImage(pil_img)
                shop_image_label.configure(image=tk_img, text="")
                shop_image_label.image = tk_img
        except Exception as e:
            print(f"[DEBUG] Failed to load shop image: {e}")

    # Shop Details
    shop_details_frame = ctk.CTkFrame(top_layer, fg_color="transparent")
    shop_details_frame.place(relx=0.4, rely=0.1, relwidth=0.55, relheight=0.8)

    shop_name_label = ctk.CTkLabel(
        shop_details_frame,
        text=shop_data.get("name", "Shop Name"),
        font=("Helvetica", 20, "bold"),
    )
    shop_name_label.pack(pady=10)

    shop_description_label = ctk.CTkLabel(
        shop_details_frame,
        text=shop_data.get("description", "No description available."),
        font=("Helvetica", 14),
        wraplength=400,
        justify="left",
    )
    shop_description_label.pack(pady=5)

    shop_address_label = ctk.CTkLabel(
        shop_details_frame,
        text=f"Address: {shop_data.get('address', 'No address provided')}",
        font=("Helvetica", 12),
    )
    shop_address_label.pack(pady=5)

    # ------------- BOTTOM LAYER (Products) -------------
    bottom_layer = ctk.CTkFrame(frame, fg_color="transparent")
    bottom_layer.place(relx=0, rely=0.4, relwidth=1, relheight=0.6)

    products_label = ctk.CTkLabel(
        bottom_layer, text="Products", font=("Helvetica", 16, "bold")
    )
    products_label.pack(pady=10)

    products_frame = ctk.CTkScrollableFrame(
        bottom_layer, fg_color="transparent", width=750, height=300
    )
    products_frame.pack(fill="both", expand=True, padx=10, pady=5)

    def create_product_card(parent, product_data):
        card_width = 130
        card_height = 210
        card = ctk.CTkFrame(
            parent,
            corner_radius=5,
            fg_color="#2b2b2b",
            width=card_width,
            height=card_height,
        )
        card.pack_propagate(False)

        image_label = ctk.CTkLabel(card, text="")
        image_label.pack(pady=5)

        product_images = product_data.get("images", [])
        if product_images:
            img_url = product_images[0].get("image_url")
            if img_url:
                fixed_url = fix_url(img_url)
                try:
                    resp = requests.get(fixed_url)
                    if resp.status_code == 200:
                        pil_img = Image.open(io.BytesIO(resp.content)).resize((70, 70))
                        tk_img = ImageTk.PhotoImage(pil_img)
                        image_label.configure(image=tk_img, text="")
                        image_label.image = tk_img
                except Exception as e:
                    print(f"[DEBUG] Product image error: {e}")

        name_text = product_data.get("name", "No Name")
        name_label = ctk.CTkLabel(
            card,
            text=name_text,
            font=("Helvetica", 11, "bold"),
            wraplength=120,
            anchor="center",
            justify="center",
        )
        name_label.pack(padx=5, pady=3)

        price_val = product_data.get("price", 0.0)
        price_label = ctk.CTkLabel(
            card,
            text=f"₫ {price_val:,.1f}",
            font=("Helvetica", 10, "bold"),
            text_color="#ff4242",
        )
        price_label.pack(side="bottom", pady=5)

        # Bind click event on card and its children.
        def on_click(event, product=product_data):
            switch_func("view_product", product)

        card.bind("<Button-1>", on_click)
        return card

    def display_products(products, container):
        for widget in container.winfo_children():
            widget.destroy()

        if not products:
            ctk.CTkLabel(container, text="No products found.").pack(pady=10)
            return

        grid_frame = ctk.CTkFrame(container, fg_color="transparent")
        grid_frame.pack(fill="both", expand=True)

        columns = 5  # 5 products per row
        for idx, product in enumerate(products):
            row = idx // columns
            col = idx % columns
            product_card = create_product_card(grid_frame, product)
            product_card.grid(row=row, column=col, padx=5, pady=5)

    # Display products
    display_products(products, products_frame)

    return frame